@@ -275,4 +275,10 @@ class ForeignKeyListStr(ForeignKey):
     from ForeignKey
 
     example: xxxx,yyyy,...
-    """
\ No newline at end of file
+    """
+
+class ForeignKeyMultiEmbeddedStr(ForeignKey):
+    """A field that has multiple object ids embed in arbitrary format
+    these ids could be from multiple unknown sources. Example would be search strings
+    in kpi
+    """
