@@ -1,6 +1,7 @@
 from itsimodels.core.base_models import BaseModel, ChildModel
 from itsimodels.core.compat import string_types
 from itsimodels.core.fields import (
+    BaseField,
     BoolField,
     DictField,
     ForeignKey,
@@ -41,6 +42,70 @@ class ValuedModel(ChildModel):
         return data
 
 
+class VisualizationOptionsModel(ValuedModel):
+    """Represents an object with a dynamic field set for visualisationOptions in Glass Table JSON files."""
+
+    def _populate(self, data, field_decoder=None):
+        """
+        Populates the model with values from data for each field
+
+        :param dict data: a dict from field name to data value
+        :param object field_decoder: Optional object to help parse a field value
+        """
+        fields = {}
+
+
+        """
+        Goal : The purpose of adding below logic is to support UDF visualization options : viz.* and splunk.* as mentioned in ITSI-26102
+
+        use of variable :
+        itsi_vo_compliant_fields - List of field aliases for the properties of visualizationOptions class. It is used when importbackup command is hit to package the Content Pack from backup ZIP file and ITSI objects are installed in the ITSI.
+        cp_vo_model_fields - List of fields for the properties of visualizationOptions class. It is used when glass table is installed using Content Pack REST API present in ITSI
+        """
+
+        itsi_vo_compliant_fields = []
+        cp_vo_model_fields = []
+
+        for name, value in list(VisualizationOptions.__dict__.items()):
+            if not isinstance(value, BaseField) or not value.alias:
+                continue
+            
+            itsi_vo_compliant_fields.append(value.alias)
+            cp_vo_model_fields.append(name)
+        
+
+        """
+        This for loop is used to support splunk.* visualization options
+        """
+        for field_name, value in data.items():
+            """
+            Skipping field dict update for 2 conditions:
+            (1) When the field_name is one of the field aliases present under visualizationOptions class, the model class for that field needs to be assigned as it is from VisualizationOptions class, since that class has type along with the original field name and its alias. This will be handled by model_fields method.
+            (2) When the field_name is one of the field present under visualizationOptions class, as these fields are handled by model_fields method
+            """
+            if field_name in itsi_vo_compliant_fields or field_name in cp_vo_model_fields:
+                continue
+            if isinstance(value, list):
+                field = ListField()
+            elif isinstance(value, dict):
+                field = DictField()
+            elif isinstance(value, bool):
+                field = BoolField()
+            elif isinstance(value, (int, float)):
+                field = NumberField()
+            else:
+                field = StringField()
+
+            fields[field_name] = field
+
+        """
+        model_fields method will get all the fields from VisualizationOptions class and add/update the `fields` dict
+        """
+        fields.update(self.model_fields())
+
+        return self._populate_with_fields(data, fields, field_decoder=field_decoder)
+
+
 class DataSourceMeta(ChildModel):
     kpi_id = ForeignKey('itsimodels.service.Kpi', alias='kpiID')
 
@@ -124,7 +189,8 @@ class Layout(ChildModel):
     type = StringField()
 
 
-class VisualizationOptions(ValuedModel):
+class VisualizationOptions(VisualizationOptionsModel):
+    """ This class is providing backwards compatibility for the below mentioned properties and working as a DynamicModel class for any new property that is not mentioned below."""
     # viz.text
     # viz.rectangle
     # viz.area
@@ -200,9 +266,9 @@ class VisualizationOptions(ValuedModel):
 
     row_background_color_odd = StringField(alias='rowBackgroundColorOdd')
 
-    row_text_color_even = StringField(alias='rowTextColorOdd')
+    row_text_color_even = StringField(alias='rowTextColorEven')
 
-    row_text_color_odd = StringField(alias='rowTextColorEven')
+    row_text_color_odd = StringField(alias='rowTextColorOdd')
 
     rx = NumberField()
 
