@@ -1,5 +1,6 @@
 from itsimodels.core.base_models import BaseModel
-from itsimodels.core.fields import ForeignKey, ListField, StringField
+from itsimodels.core.compat import string_types
+from itsimodels.core.fields import ForeignKey, ForeignKeyList, ListField, StringField
 from itsimodels.service import EntityRule, Kpi
 
 
@@ -14,6 +15,10 @@ class ServiceTemplate(BaseModel):
 
     kpis = ListField(Kpi)
 
+    linked_services = ForeignKeyList('itsimodels.service.Service')
+
+    sync_status = StringField()
+
     team_id = ForeignKey('itsimodels.team.Team', default='default_itsi_security_group', alias='sec_grp')
 
-    template_tags = ListField(list)
+    template_tags = ListField(string_types)
